@@ -721,9 +721,8 @@ double ServoCalcs::velocityScalingFactorForSingularity(const Eigen::VectorXd& co
 
   Eigen::JacobiSVD<Eigen::MatrixXd> new_svd(new_jacobian);
   double new_condition = new_svd.singularValues()(0) / new_svd.singularValues()(new_svd.singularValues().size() - 1);
-  // If new_condition < ini_condition, the singular vector does point towards a
-  // singularity. Otherwise, flip its direction.
-  if (ini_condition >= new_condition)
+  // If new_condition < ini_condition, the singular vector points away from the singularity. If so, flip its direction.
+  if (new_condition < ini_condition)
   {
     vector_toward_singularity *= -1;
   }
